"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const vscode_languageserver_1 = require("vscode-languageserver");
const vscode_languageserver_2 = require("vscode-languageserver");
function isWindows() {
    return /^win/.test(process.platform);
}
exports.isWindows = isWindows;
function uriToPath(uri) {
    const p = path.resolve(uri.replace(/file:\/\/\//, ''));
    return isWindows() ? p.replace(/\//g, '\\') : p;
}
exports.uriToPath = uriToPath;
function pathToUri(p) {
    return 'file://' + (isWindows() ? '/' + p.replace(/\//g, '/') : p);
}
exports.pathToUri = pathToUri;
function tsServerLocationToLspPosition(location) {
    return {
        line: location.line - 1,
        character: location.offset - 1
    };
}
exports.tsServerLocationToLspPosition = tsServerLocationToLspPosition;
function tsServerFileSpanToLspLocation(fileSpan) {
    return {
        uri: pathToUri(fileSpan.file),
        range: {
            start: tsServerLocationToLspPosition(fileSpan.start),
            end: tsServerLocationToLspPosition(fileSpan.end)
        }
    };
}
exports.tsServerFileSpanToLspLocation = tsServerFileSpanToLspLocation;
exports.completionKindsMapping = {
    class: vscode_languageserver_2.CompletionItemKind.Class,
    constructor: vscode_languageserver_2.CompletionItemKind.Constructor,
    enum: vscode_languageserver_2.CompletionItemKind.Enum,
    field: vscode_languageserver_2.CompletionItemKind.Field,
    file: vscode_languageserver_2.CompletionItemKind.File,
    function: vscode_languageserver_2.CompletionItemKind.Function,
    interface: vscode_languageserver_2.CompletionItemKind.Interface,
    keyword: vscode_languageserver_2.CompletionItemKind.Keyword,
    method: vscode_languageserver_2.CompletionItemKind.Method,
    module: vscode_languageserver_2.CompletionItemKind.Module,
    property: vscode_languageserver_2.CompletionItemKind.Property,
    reference: vscode_languageserver_2.CompletionItemKind.Reference,
    snippet: vscode_languageserver_2.CompletionItemKind.Snippet,
    text: vscode_languageserver_2.CompletionItemKind.Text,
    unit: vscode_languageserver_2.CompletionItemKind.Unit,
    value: vscode_languageserver_2.CompletionItemKind.Value,
    variable: vscode_languageserver_2.CompletionItemKind.Variable
};
exports.symbolKindsMapping = {
    'enum member': vscode_languageserver_1.SymbolKind.Constant,
    'JSX attribute': vscode_languageserver_1.SymbolKind.Property,
    'local class': vscode_languageserver_1.SymbolKind.Class,
    'local function': vscode_languageserver_1.SymbolKind.Function,
    'local var': vscode_languageserver_1.SymbolKind.Variable,
    'type parameter': vscode_languageserver_1.SymbolKind.Variable,
    alias: vscode_languageserver_1.SymbolKind.Variable,
    class: vscode_languageserver_1.SymbolKind.Class,
    const: vscode_languageserver_1.SymbolKind.Constant,
    constructor: vscode_languageserver_1.SymbolKind.Constructor,
    enum: vscode_languageserver_1.SymbolKind.Enum,
    field: vscode_languageserver_1.SymbolKind.Field,
    file: vscode_languageserver_1.SymbolKind.File,
    function: vscode_languageserver_1.SymbolKind.Function,
    getter: vscode_languageserver_1.SymbolKind.Method,
    interface: vscode_languageserver_1.SymbolKind.Interface,
    let: vscode_languageserver_1.SymbolKind.Variable,
    method: vscode_languageserver_1.SymbolKind.Method,
    module: vscode_languageserver_1.SymbolKind.Module,
    parameter: vscode_languageserver_1.SymbolKind.Variable,
    property: vscode_languageserver_1.SymbolKind.Property,
    setter: vscode_languageserver_1.SymbolKind.Method,
    var: vscode_languageserver_1.SymbolKind.Variable
};
class Deferred {
    constructor() {
        this.promise = new Promise((resolve, reject) => {
            this.resolve = resolve;
            this.reject = reject;
        });
    }
}
exports.Deferred = Deferred;
